@@ -8,13 +8,6 @@ POK = Instruction(
         ]
     )
 
-LON = Instruction(
-        'LON',
-        0x01,
-        [
-        ]
-    )
-
 DEL = Instruction(
         'DEL',
         0x02,
@@ -23,13 +16,6 @@ DEL = Instruction(
         ]
     )
 
-LOF = Instruction(
-        'LOF',
-        0x03,
-        [
-        ]
-    )
-
 JMP = Instruction(
         'JMP',
         0x04,
@@ -244,11 +230,30 @@ MOV = Instruction(
         ]
     )
 
+SCS = Instruction(
+        'SCS',
+        0x1B,
+        [
+            Argument('x', BYTE),
+            Argument('y', BYTE),
+            Argument('charstart', BYTE),
+        ]
+    )
+
+SCC = Instruction(
+        'SCC',
+        0x1C,
+        [
+            Argument('x', BYTE),
+            Argument('y', BYTE),
+            Argument('width', BYTE),
+            Argument('height', BYTE),
+        ]
+    )
+
 instructions = {
         0x00: POK,
-        0x01: LON,
         0x02: DEL,
-        0x03: LOF,
         0x04: JMP,
         0x05: ADB,
         0x06: ADI,
@@ -272,4 +277,6 @@ instructions = {
         0x18: SCT,
         0x19: DUB,
         0x1A: MOV,
+        0x1B: SCS,
+        0x1C: SCC,
 }
